@@ -20,6 +20,7 @@
 MeasureSurvGonenC = R6Class("MeasureSurvGonenC",
   inherit = MeasureSurv,
   public = list(
+    #' @description Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       super$initialize(
         id = "surv.gonenC",
@@ -28,9 +29,11 @@ MeasureSurvGonenC = R6Class("MeasureSurvGonenC",
         packages = "survAUC",
         predict_type = "lp"
       )
-    },
+    }
+  ),
 
-    score_internal = function(prediction, ...) {
+  private = list(
+    .score = function(prediction, ...) {
       survAUC::GHCI(prediction$lp)
     }
   )
