@@ -1,6 +1,5 @@
 #' @template surv_measure
 #' @templateVar title Standard Error of Root Mean Squared Error
-#' @templateVar inherit [MeasureSurv]
 #' @templateVar fullname MeasureSurvRMSESE
 #'
 #' @description
@@ -16,6 +15,7 @@
 MeasureSurvRMSESE = R6::R6Class("MeasureSurvRMSESE",
   inherit = MeasureSurv,
   public = list(
+    #' @description Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       super$initialize(
         id = "surv.rmseSE",
@@ -23,9 +23,11 @@ MeasureSurvRMSESE = R6::R6Class("MeasureSurvRMSESE",
         minimize = TRUE,
         predict_type = "response"
       )
-    },
+    }
+  ),
 
-    score_internal = function(prediction, ...) {
+  private = list(
+    .score = function(prediction, ...) {
       mse = surv_mse(prediction$truth, prediction$response)
       mse$se/(2*sqrt(mean(mse$mse)))
     }
