@@ -1,6 +1,7 @@
 context("surv.cvglmnet")
 
 test_that("autotest", {
+  skip_on_cran()
   learner = mlr_learners$get("surv.cvglmnet")
   expect_learner(learner)
   result = run_autotest(learner)
@@ -8,7 +9,9 @@ test_that("autotest", {
 })
 
 test_that("ctrl.pars",{
-  task = tsk("rats")
+  skip_on_cran()
+  set.seed(1)
+  task = tgen("simsurv")$generate(20)
   learner = mlr_learners$get("surv.cvglmnet")
   learner$param_set$values = list(mxit = 90, s = 0.1)
   expect_silent(expect_prediction_surv(learner$train(task)$predict(task)))
