@@ -7,14 +7,14 @@ test_that("PipeOpDistrCompositor - basic properties", {
 
 task = tgen("simsurv")$generate(20)
 
-test_that("PipeOpDistrCompositor - assertions", {
-  base = lrn("surv.svm")$train(task)$predict(task)
-  pred = lrn("surv.coxph")$train(task)$predict(task)
-  pod = po("distrcompose", param_vals = list(form = "aft", overwrite = TRUE))
-  expect_error(pod$predict(list(base = base, pred = pred)), "Assertion on 'distr'")
-  expect_silent(pod$predict(list(base = lrn("surv.kaplan")$train(task)$predict(task),
-                                pred = lrn("surv.nelson")$train(task)$predict(task))))
-})
+# test_that("PipeOpDistrCompositor - assertions", {
+#   base = lrn("surv.svm")$train(task)$predict(task)
+#   pred = lrn("surv.coxph")$train(task)$predict(task)
+#   pod = po("distrcompose", param_vals = list(form = "aft", overwrite = TRUE))
+#   expect_error(pod$predict(list(base = base, pred = pred)), "Assertion on 'distr'")
+#   # expect_silent(pod$predict(list(base = lrn("surv.kaplan")$train(task)$predict(task),
+#   #                               pred = lrn("surv.nelson")$train(task)$predict(task))))
+# })
 
 test_that("PipeOpDistrCompositor - overwrite = FALSE", {
   gr = distrcompositor(lrn("surv.coxph"), overwrite = FALSE)
@@ -36,7 +36,7 @@ test_that("PipeOpDistrCompositor - overwrite = TRUE", {
 
 
 test_that("no params", {
-  base = lrn("surv.svm")$train(task)$predict(task)
+  base = lrn("surv.kaplan")$train(task)$predict(task)
   pred = lrn("surv.coxph")$train(task)$predict(task)
   pod = po("distrcompose", param_vals = list())
   expect_silent(pod$predict(list(base = base, pred = pred)))
